# Troubleshooting

Troubleshooting covers Joins don’t work, Nested objects don’t appear, Pagination counts look wrong with joins.

## Sections

- [Joins don’t work](joins-don-t-work.md)
- [Nested objects don’t appear](nested-objects-don-t-appear.md)
- [Pagination counts look wrong with joins](pagination-counts-look-wrong-with-joins.md)
- [Performance tips](performance-tips.md)
